@@ -35,7 +35,7 @@ use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
-our @EXPORT = qw($select_chaining_setup);
+our @EXPORT = qw($select_fullautoapi_setup);
 
 use Net::FullAuto::Cloud::fa_amazon;
 use Net::FullAuto::FA_Core qw[cmd_raw $localhost];
@@ -44,7 +44,7 @@ my $home_dir=File::HomeDir->my_home.'/';
 my $username=getlogin || getpwuid($<);
 my $do;my $ad;my $prompt;
 
-my $configure_chaining=sub {
+my $configure_fullautoapi=sub {
 
    my $selection=$_[0]||'';
    my ($stdout,$stderr)=('','');
@@ -498,7 +498,7 @@ END
       Crypt::PassGen
 
    );
-   my $install_chaining=<<'END';
+   my $install_fullautoapi=<<'END';
 
           o o    o .oPYo. ooooo    .oo o     o     o o    o .oPYo.
           8 8b   8 8        8     .P 8 8     8     8 8b   8 8    8
@@ -535,7 +535,7 @@ END
       sleep 1;
       print $show;
       if ($module eq 'Catalyst::Runtime') {
-         print $install_chaining;
+         print $install_fullautoapi;
          sleep 10;
       }
       unless ($^O eq 'cygwin') {
@@ -2000,18 +2000,18 @@ END
 
 };
 
-my $standup_chaining=sub {
+my $standup_fullautoapi=sub {
 
-   my $catalyst="]T[{select_chaining_setup}";
+   my $catalyst="]T[{select_fullautoapi_setup}";
    my $cnt=0;
-   $configure_chaining->($catalyst);
+   $configure_fullautoapi->($catalyst);
    return '{choose_demo_setup}<';
 
 };
 
-my $chaining_setup_summary=sub {
+my $fullautoapi_setup_summary=sub {
 
-   package chaining_setup_summary;
+   package fullautoapi_setup_summary;
    use JSON::XS;
    my $region="]T[{awsregions}";
    $region=~s/^"//;
@@ -2022,7 +2022,7 @@ my $chaining_setup_summary=sub {
    my $money=$type;
    $money=~s/^.*-> \$(.*?) +(?:[(].+[)] )*\s*per hour$/$1/;
    $type=substr($type,0,(index $type,' ->')-3);
-   my $catalyst="]T[{select_chaining_setup}";
+   my $catalyst="]T[{select_fullautoapi_setup}";
    $catalyst=~s/^"//;
    $catalyst=~s/"$//;
    print "REGION=$region and TYPE=$type\n";
@@ -2076,7 +2076,7 @@ END
       Item_1 => {
 
          Text => "I accept the \$$cost$cents per hour cost",
-         Result => $standup_chaining,
+         Result => $standup_fullautoapi,
 
       },
       Item_2 => {
@@ -2099,10 +2099,10 @@ END
 
 };
 
-our $select_chaining_setup=sub {
+our $select_fullautoapi_setup=sub {
 
    my @options=('FullAuto© Automation API on 1 Server');
-   my $chaining_setup_banner=<<'END';
+   my $fullautoapi_setup_banner=<<'END';
 
                      _    ___     _ _   _       _                     
                    ((_)  | __|  _| | | /_\ _  _| |_  |                   
@@ -2124,20 +2124,20 @@ our $select_chaining_setup=sub {
    navigate backwards and make new selections with the [<] LEFTARROW key.
 
 END
-   my %select_chaining_setup=(
+   my %select_fullautoapi_setup=(
 
-      Name => 'select_chaining_setup',
+      Name => 'select_fullautoapi_setup',
       Item_1 => {
 
          Text => ']C[',
          Convey => \@options,
-         Result => $standup_chaining,
+         Result => $standup_fullautoapi,
 
       },
       Scroll => 1,
-      Banner => $chaining_setup_banner,
+      Banner => $fullautoapi_setup_banner,
    );
-   return \%select_chaining_setup
+   return \%select_fullautoapi_setup
 
 };
 
